==> dart_icalendar-1.0.7.tar.gz: test/test.helper.dart <==
import 'dart:math';

import 'package:dart_icalendar/models/event_model.dart';
import 'package:dart_icalendar/models/recurrence_model.dart';

class TestHelper {
  List<Event> createEvents(int count) {
    List<Event> events = [];
    for (int i = 0; i < count; i++) {
      Availability? availability;
      availability =
          Availability.values[Random().nextInt(Availability.values.length)];
      String sumary = availability.toString().split('.').last;
      String description = availability.toString().split('.').last;
      DateTime stamp = DateTime.now();
      DateTime created = DateTime.now();
      DateTime lastUpdated = DateTime.now();
      DateTime start = DateTime.now()
          .subtract(Duration(days: Random().nextInt(1850)))
          .add(Duration(days: Random().nextInt(1850)));
      DateTime end = start.add(Duration(days: Random().nextInt(1850)));
      int sequence = Random().nextInt(4);
      String transparency = "OPAQUE";
      RecurrenceRule? recurrenceRule;
      if (Random().nextInt(100) > 66) {
        int interval = Random().nextInt(4);
        int? count = Random().nextInt(100) > 50 ? Random().nextInt(100) : null;
        DateTime? until = Random().nextInt(100) > 50
            ? DateTime.now().add(Duration(days: Random().nextInt(1850)))
            : null;
        Frequency frequency =
            Frequency.values[Random().nextInt(Frequency.values.length)];
        recurrenceRule = RecurrenceRule(
          interval: interval,
          count: count,
          until: until,
          frequency: frequency,
        );
        switch (frequency) {
          case Frequency.SECONDLY:
            recurrenceRule.bySecond = [Random().nextInt(60)];
            break;
          case Frequency.MINUTELY:
            recurrenceRule.byMinute = [Random().nextInt(60)];
            break;
          case Frequency.HOURLY:
            recurrenceRule.byHour = [Random().nextInt(24)];
            break;
          case Frequency.DAILY:
            List<DayOfWeek> daysOfWeek = [];
            for (int i = 0; i < Random().nextInt(7); i++) {
              daysOfWeek.add(DayOfWeek(
                  weekday:
                      Weekday.values[Random().nextInt(Weekday.values.length)]));
            }
            recurrenceRule.byDay = daysOfWeek;
            break;
          case Frequency.WEEKLY:
            List<DayOfWeek> daysOfWeek = [];
            for (int i = 0; i < Random().nextInt(7); i++) {
              daysOfWeek.add(DayOfWeek(
                  weekday:
                      Weekday.values[Random().nextInt(Weekday.values.length)]));
            }
            recurrenceRule.byDay = daysOfWeek;
            break;
          case Frequency.MONTHLY:
            recurrenceRule.byMonth = [Random().nextInt(12)];
            break;
          case Frequency.YEARLY:
            recurrenceRule.byYearDay = [Random().nextInt(365)];
            break;
        }
      }

      var event = Event(
        uid: Random().nextInt(4294967296).toString(),
        summary: sumary,
        description: description,
        stamp: stamp,
        created: created,
        lastModified: lastUpdated,
        startDate: start,
        endDate: end,
        sequence: sequence,
        transparency: transparency,
        recurrenceRule: recurrenceRule,
      );
      event.availability = availability;
      events.add(event);
    }
    return events;
  }
}

==> dart_icalendar-1.0.11.tar.gz: test/test.helper.dart <==
import 'dart:math';

import 'package:dart_icalendar/models/event_model.dart';
import 'package:dart_icalendar/models/recurrence_model.dart';

class TestHelper {
  List<Event> createEvents(int count) {
    List<Event> events = [];
    for (int i = 0; i < count; i++) {
      Availability? availability;
      availability =
          Availability.values[Random().nextInt(Availability.values.length)];
      String sumary = availability.toString().split('.').last;
      String description = availability.toString().split('.').last;
      DateTime stamp = DateTime.now();
      DateTime created = DateTime.now();
      DateTime lastUpdated = DateTime.now();
      DateTime start = DateTime.now()
          .subtract(Duration(days: Random().nextInt(1850)))
          .add(Duration(days: Random().nextInt(1850)));
      DateTime end = start.add(Duration(days: Random().nextInt(1850)));
      int sequence = Random().nextInt(4);
      String transparency = "OPAQUE";
      RecurrenceRule? recurrenceRule;
      if (Random().nextInt(100) > 66) {
        int interval = Random().nextInt(4) + 1;
        int? count =
            Random().nextInt(100) > 50 ? Random().nextInt(100) + 1 : null;
        DateTime? until = Random().nextInt(100) > 50
            ? DateTime.now().add(Duration(days: Random().nextInt(1850)))
            : null;
        Frequency frequency =
            Frequency.values[Random().nextInt(Frequency.values.length)];
        recurrenceRule = RecurrenceRule(
          interval: interval,
          count: count,
          until: until,
          frequency: frequency,
        );
        switch (frequency) {
          case Frequency.SECONDLY:
            recurrenceRule.bySecond = [Random().nextInt(59) + 1];
            break;
          case Frequency.MINUTELY:
            recurrenceRule.byMinute = [Random().nextInt(59) + 1];
            break;
          case Frequency.HOURLY:
            recurrenceRule.byHour = [Random().nextInt(23) + 1];
            break;
          case Frequency.DAILY:
            List<DayOfWeek> daysOfWeek = [];
            for (int i = 0; i < Random().nextInt(6) + 1; i++) {
              daysOfWeek.add(DayOfWeek(
                  weekday:
                      Weekday.values[Random().nextInt(Weekday.values.length)]));
            }
            recurrenceRule.byDay = daysOfWeek;
            break;
          case Frequency.WEEKLY:
            List<DayOfWeek> daysOfWeek = [];
            for (int i = 0; i < Random().nextInt(6) + 1; i++) {
              daysOfWeek.add(DayOfWeek(
                  weekday:
                      Weekday.values[Random().nextInt(Weekday.values.length)]));
            }
            recurrenceRule.byDay = daysOfWeek;
            break;
          case Frequency.MONTHLY:
            recurrenceRule.byMonth = [Random().nextInt(11) + 1];
            break;
          case Frequency.YEARLY:
            recurrenceRule.byYearDay = [Random().nextInt(364) + 1];
            break;
        }
      }

      var event = Event(
        uid: Random().nextInt(100000).toString(),
        summary: sumary,
        description: description,
        stamp: stamp,
        created: created,
        lastModified: lastUpdated,
        startDate: start,
        endDate: end,
        sequence: sequence,
        transparency: transparency,
        recurrenceRule: recurrenceRule,
      );
      event.availability = availability;
      events.add(event);
    }
    return events;
  }
}
